Module: Gempilot::CLI::GemBuilder

Included in:
Commands::Create
Defined in:
lib/gempilot/cli/gem_builder.rb

Overview

File rendering and directory creation logic for scaffolding a new gem.

Expects the including class to provide Generator methods (mkdir, erb, chmod, cp, cd, sh) and the following instance variables: @gem_name, @require_path, @module_name, @hyphenated, @test_framework, @branch.